Glossary
--------

ordered set:
   A data structure in which every element appears only once and every
   element has an index that identifies it.

stream:
   A data structure that represents a “flow” or sequence of data items
   from one place to another. In C++ streams are used for input and
   output.

accumulator:
   A variable used inside a loop to accumulate a result, often by
   getting something added or concatenated during each iteration.

.. dragndrop:: glossary15
    :feedback: Try again!
    :match_1: ordered set|||a data structure in which every element appears only once and every element has an index that identifies it
    :match_2: stream|||a data structure that represents a “flow” or sequence of data items from one place to another. In C++ streams are used for input and output
    :match_3: accumulator|||a variable used inside a loop to accumulate a result, often by getting something added or concatenated during each iteration.

    Match the vocabulary word with its definition.
